#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 typed-process
version:              0.2.6.0
visibility:           public
id:                   typed-process-0.2.6.0-9KWu5OKUe9BBdD96SkplgB
key:                  typed-process-0.2.6.0-9KWu5OKUe9BBdD96SkplgB
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://haskell-lang.org/library/typed-process
synopsis:             Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://haskell-lang.org/library/typed-process>

category:             System
abi:                  8f83b9ab3bdd14b084c3beb9d3b4be7a
exposed:              True
exposed-modules:      System.Process.Typed System.Process.Typed.Internal
hidden-modules:       Paths_typed_process
import-dirs:          /usr/lib/ghc-8.10.5/site-local/typed-process-0.2.6.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/typed-process-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/typed-process-0.2.6.0
hs-libraries:         HStyped-process-0.2.6.0-9KWu5OKUe9BBdD96SkplgB
depends:
    async-2.2.3-EEZ7ScAbhsHIRG0TBpna8H base-4.14.2.0
    bytestring-0.10.12.0 process-1.6.9.0 stm-2.5.0.1
    transformers-0.5.6.2 unliftio-core-0.2.0.1-1ibY1oF6Hkc5ZYjZ4yW3Lp

haddock-interfaces:
    /usr/share/doc/haskell-typed-process/html/typed-process.haddock

haddock-html:         /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

